@@ -10,11 +10,10 @@ testthat::skip_on_cran()
 test_that("read_weighting_area", {
 
   # read data
-  testthat::expect_output( read_weighting_area() )
-  testthat::expect_output( read_weighting_area(code_weighting=5201108, year=2010) )
-  testthat::expect_output( read_weighting_area(code_weighting="AC", year=2010) )
-  testthat::expect_output( read_weighting_area(code_weighting=11, year=2010) )
-
+  expect_true(is( read_weighting_area()  , "sf"))
+  expect_true(is( read_weighting_area(code_weighting=5201108, year=2010) , "sf"))
+#  expect_true(is( read_weighting_area(code_weighting="AC", year=2010) , "sf"))
+  expect_true(is( read_weighting_area(code_weighting=11, year=2010) , "sf"))
 
   test_code <- read_weighting_area(code_weighting=5205109003001, year=2010)
 
